diff --git a/build.gradle.kts b/build.gradle.kts
index 939b23104..51df363c5 100644
--- a/build.gradle.kts
+++ b/build.gradle.kts
@@ -10,7 +10,7 @@ plugins {
 }
 
 group = "net.minecraft"
-version = "7.2 Prerelease 1"
+version = "7.2 Prerelease 2"
 val buildChannel = "PRERELEASE"
 
 run {
diff --git a/src/main/java/net/minecraft/client/gui/GuiPhotoMode.java b/src/main/java/net/minecraft/client/gui/GuiPhotoMode.java
index 0af62e9b7..be7fa667d 100644
--- a/src/main/java/net/minecraft/client/gui/GuiPhotoMode.java
+++ b/src/main/java/net/minecraft/client/gui/GuiPhotoMode.java
@@ -135,7 +135,11 @@ public class GuiPhotoMode extends GuiScreen
         buttonRotateRight = new GuiButton(1, width / 2 + 59 + 2 + 1, height - 20, 20, 20, ">");
         buttonTakeScreenshot = new GuiButton(4, width / 2 - 59, height - 20, 98, 20, i18n.translateKey("gui.photo_mode.button.take_screenshot"));
         buttonOpenScreenshotFolder = new GuiListenerTextureButton(30, "/assets/minecraft/textures/gui/gui.png", buttonTakeScreenshot.getWidth() + buttonTakeScreenshot.getX() + 1, buttonTakeScreenshot.getY(), 100, 106 - 20, 20, 20);
-        buttonOpenScreenshotFolder.setActionListener(() -> Utils.openDirectory(new File(mc.getMinecraftDir(), "screenshots")));
+        buttonOpenScreenshotFolder.setActionListener(() -> {
+            File f = new File(mc.getMinecraftDir(), "screenshots");
+            f.mkdirs();
+            Utils.openDirectory(f);
+        });
 
         buttonCenterScreen = new GuiButton(10, width - 120, 0, 120, 20, i18n.translateKey("gui.photo_mode.button.center_camera"));
         buttonShowPlayer = new GuiButton(11, width - 120, 0, 120, 20, "");
diff --git a/src/main/java/net/minecraft/client/gui/MainMenuBackground.java b/src/main/java/net/minecraft/client/gui/MainMenuBackground.java
index 0afa0d3eb..b20dc8165 100644
--- a/src/main/java/net/minecraft/client/gui/MainMenuBackground.java
+++ b/src/main/java/net/minecraft/client/gui/MainMenuBackground.java
@@ -123,7 +123,7 @@ public class MainMenuBackground {
 	private void drawImage(Background background, float alpha) {
 		glEnable(GL_TEXTURE_2D);
 		glBindTexture(GL_TEXTURE_2D, background.texture);
-		glColor4d(1.0, 1.0, 1.0, alpha);
+		glColor4d(0.6, 0.6, 0.6, alpha);
 
 		int border = 1;
 
@@ -160,6 +160,7 @@ public class MainMenuBackground {
 		
 		Tessellator tessellator = Tessellator.instance;
 		tessellator.startDrawingQuads();
+		tessellator.setColorOpaque_F(0.75f, 0.75f, 0.75f);
 		tessellator.drawRectangleWithUV(x, y, w, h, uborder, vborder, 1.0 - uborder * 2.0f, 1.0 - vborder * 2.0f);
 		tessellator.draw();
 	}
diff --git a/src/main/java/net/minecraft/client/gui/options/data/OptionsPages.java b/src/main/java/net/minecraft/client/gui/options/data/OptionsPages.java
index bcab897a5..3683e1d34 100644
--- a/src/main/java/net/minecraft/client/gui/options/data/OptionsPages.java
+++ b/src/main/java/net/minecraft/client/gui/options/data/OptionsPages.java
@@ -50,7 +50,11 @@ public abstract class OptionsPages
         )
         .withComponent(new ShortcutComponent("gui.options.page.general.button.edit_hud", () -> mc.displayGuiScreen(new GuiHudDesigner(mc.currentScreen))))
         .withComponent(new ShortcutComponent("gui.options.page.general.button.open_worlds_folder", () -> Utils.openDirectory(new File(mc.getMinecraftDir(), "saves"))))
-        .withComponent(new ShortcutComponent("gui.options.page.general.button.open_screenshots_folder", () -> Utils.openDirectory(new File(mc.getMinecraftDir(), "screenshots"))))
+        .withComponent(new ShortcutComponent("gui.options.page.general.button.open_screenshots_folder", () -> {
+            File f = new File(mc.getMinecraftDir(), "screenshots");
+            f.mkdirs();
+            Utils.openDirectory(f);
+        }))
     );
 
     public static final OptionsPage AUDIO = register(new OptionsPage("gui.options.page.audio.title", new ItemStack(Item.recordCat))
diff --git a/src/main/java/net/minecraft/client/option/KeyBinding.java b/src/main/java/net/minecraft/client/option/KeyBinding.java
index 8b6c8c33f..32892d266 100644
--- a/src/main/java/net/minecraft/client/option/KeyBinding.java
+++ b/src/main/java/net/minecraft/client/option/KeyBinding.java
@@ -90,6 +90,14 @@ public class KeyBinding {
 		return keyCode;
 	}
 
+	public InputDevice getDefaultInputDevice() {
+		return defaultInputDevice;
+	}
+
+	public int getDefaultKeyCode() {
+		return defaultKeyCode;
+	}
+
 	public boolean isPressed() {
 		if(inputDevice != null) {
 			return inputDevice.isPressed(keyCode);
